@@ -4,13 +4,11 @@ Agent loading and metadata extraction.
 Handles dynamic loading of agent modules and extraction of agent metadata.
 """
 
-import contextlib
 import importlib.util
 import io
 import logging
 import os
 import sys
-import warnings
 from pathlib import Path
 from typing import Any, Dict, Optional, Tuple
 
@@ -111,6 +109,7 @@ def _ensure_package_loaded(package_root: Path, package_name: str) -> None:
         # This avoids import errors from parent packages while still
         # satisfying Python's import machinery for relative imports
         import types
+
         pkg_module = types.ModuleType(pkg)
 
         # Set package attributes - critical for import machinery
@@ -243,7 +242,8 @@ def extract_agent_metadata(agent: Any) -> Dict[str, Any]:
         # Clean up model_id if it's a long AWS model string
         if model_id and isinstance(model_id, str):
             # Extract meaningful part from AWS model IDs
-            # e.g., "us.anthropic.claude-sonnet-4-5-20250929-v1:0" -> "Claude Sonnet 4.5"
+            # Example: "us.anthropic.claude-sonnet-4-5-20250929-v1:0"
+            # -> "Claude Sonnet 4.5"
             if "claude-sonnet" in model_id.lower():
                 if "4-5" in model_id or "4.5" in model_id:
                     model_id = "Claude Sonnet 4.5"
